@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: chunked-data
 version: 0.2.0
-id: chunked-data-0.2.0-0e06c4c78d0115de9d8c000bb08df0f5
-key: chunk_6xPEbxfzN9G146uTUNE83W
+id: chunked-data-0.2.0-58ae738dfc85ce16f60338cfe67845f2
+key: chunk_4C45Ll92wi64eOLPoLe5ZV
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/chunked-data
@@ -20,15 +20,15 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/chunked-data-0.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/chunked-data-0.2.0
-hs-libraries: HSchunked-data-0.2.0-6xPEbxfzN9G146uTUNE83W
+hs-libraries: HSchunked-data-0.2.0-4C45Ll92wi64eOLPoLe5ZV
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    mono-traversable-0.10.1.1-7ac62162d55f8d714083ba886bfb5efd
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    mono-traversable-0.10.1.1-d8076f94d0f4a1c39fe9d5feae3b294a
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
 haddock-interfaces: /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock
